@@ -29,14 +29,20 @@
 #include <gconf/gconf-client.h>
 
 #define GCONF_TYPE_EDITOR_WINDOW		  (gconf_editor_window_get_type ())
-#define GCONF_EDITOR_WINDOW(obj)		  (GTK_CHECK_CAST ((obj), GCONF_TYPE_EDITOR_WINDOW, GConfEditorWindow))
-#define GCONF_EDITOR_WINDOW_CLASS(klass)	  (GTK_CHECK_CLASS_CAST ((klass), GCONF_TYPE_EDITOR_WINDOW, GConfEditorWindowClass))
-#define GCONF_IS_EDITOR_WINDOW(obj)	  (GTK_CHECK_TYPE ((obj), GCONF_TYPE_EDITOR_WINDOW))
-#define GCONF_IS_EDITOR_WINDOW_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((obj), GCONF_TYPE_EDITOR_WINDOW))
-#define GCONF_EDITOR_WINDOW_GET_CLASS(obj)   (GTK_CHECK_GET_CLASS ((obj), GCONF_TYPE_EDITOR_WINDOW, GConfEditorWindowClass))
+#define GCONF_EDITOR_WINDOW(obj)		  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCONF_TYPE_EDITOR_WINDOW, GConfEditorWindow))
+#define GCONF_EDITOR_WINDOW_CLASS(klass)	  (G_TYPE_CHECK_CLASS_CAST ((klass), GCONF_TYPE_EDITOR_WINDOW, GConfEditorWindowClass))
+#define GCONF_IS_EDITOR_WINDOW(obj)	  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCONF_TYPE_EDITOR_WINDOW))
+#define GCONF_IS_EDITOR_WINDOW_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((obj), GCONF_TYPE_EDITOR_WINDOW))
+#define GCONF_EDITOR_WINDOW_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GCONF_TYPE_EDITOR_WINDOW, GConfEditorWindowClass))
 
 #define RECENT_LIST_MAX_SIZE 20
 
+enum {
+        GCONF_EDITOR_WINDOW_TYPE_NORMAL,
+        GCONF_EDITOR_WINDOW_TYPE_DEFAULTS,
+        GCONF_EDITOR_WINDOW_TYPE_MANDATORY
+};
+
 enum {
 	GCONF_EDITOR_WINDOW_OUTPUT_WINDOW_NONE,
 	GCONF_EDITOR_WINDOW_OUTPUT_WINDOW_SEARCH,
@@ -50,9 +56,9 @@ typedef struct _GConfEditorWindowClass GConfEditorWindowClass;
 struct _GConfEditorWindow {
 	GtkWindow parent_instance;
 
+	int type;
 	GConfClient *client;
 
-
 	GtkWidget *tree_view;
 	GtkTreeModel *tree_model;
 	GtkTreeModel *sorted_tree_model;
