@@ -24,17 +24,17 @@
 #include <gconf/gconf-client.h>
 
 #define GCONF_TYPE_LIST_MODEL		  (gconf_list_model_get_type ())
-#define GCONF_LIST_MODEL(obj)		  (GTK_CHECK_CAST ((obj), GCONF_TYPE_LIST_MODEL, GConfListModel))
-#define GCONF_LIST_MODEL_CLASS(klass)	  (GTK_CHECK_CLASS_CAST ((klass), GCONF_TYPE_LIST_MODEL, GConfListModelClass))
-#define GCONF_IS_LIST_MODEL(obj)	  (GTK_CHECK_TYPE ((obj), GCONF_TYPE_LIST_MODEL))
-#define GCONF_IS_LIST_MODEL_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((obj), GCONF_TYPE_LIST_MODEL))
-#define GCONF_LIST_MODEL_GET_CLASS(obj)   (GTK_CHECK_GET_CLASS ((obj), GCONF_TYPE_LIST_MODEL, GConfListModelClass))
+#define GCONF_LIST_MODEL(obj)		  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCONF_TYPE_LIST_MODEL, GConfListModel))
+#define GCONF_LIST_MODEL_CLASS(klass)	  (G_TYPE_CHECK_CLASS_CAST ((klass), GCONF_TYPE_LIST_MODEL, GConfListModelClass))
+#define GCONF_IS_LIST_MODEL(obj)	  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCONF_TYPE_LIST_MODEL))
+#define GCONF_IS_LIST_MODEL_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((obj), GCONF_TYPE_LIST_MODEL))
+#define GCONF_LIST_MODEL_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GCONF_TYPE_LIST_MODEL, GConfListModelClass))
 
 typedef struct _GConfListModel GConfListModel;
 typedef struct _GConfListModelClass GConfListModelClass;
 
 enum {
-	GCONF_LIST_MODEL_ICON_COLUMN,
+	GCONF_LIST_MODEL_ICON_NAME_COLUMN,
 	GCONF_LIST_MODEL_KEY_NAME_COLUMN,
 	GCONF_LIST_MODEL_KEY_PATH_COLUMN,
 	GCONF_LIST_MODEL_VALUE_COLUMN,
